==> okteta_4.13.0.orig.tar.xz: okteta-4.13.0/kasten/controllers/view/libbytearraychecksum/algorithm/nobytearraychecksumparametersetedit.cpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "nobytearraychecksumparametersetedit.h"


const char* const NoByteArrayChecksumParameterSetEdit::Id = "None";


NoByteArrayChecksumParameterSetEdit::NoByteArrayChecksumParameterSetEdit( QWidget* parent )
 : AbstractByteArrayChecksumParameterSetEdit( parent )
{}

void NoByteArrayChecksumParameterSetEdit::setParameterSet( const AbstractByteArrayChecksumParameterSet* parameterSet )
{
    Q_UNUSED( parameterSet );
}

void NoByteArrayChecksumParameterSetEdit::getParameterSet( AbstractByteArrayChecksumParameterSet* parameterSet ) const
{
    Q_UNUSED( parameterSet );
}

NoByteArrayChecksumParameterSetEdit::~NoByteArrayChecksumParameterSetEdit()
{}

==> okteta_17.12.3.orig.tar.xz: okteta-17.12.3/kasten/controllers/view/libbytearraychecksum/algorithm/nobytearraychecksumparametersetedit.cpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "nobytearraychecksumparametersetedit.h"


const char NoByteArrayChecksumParameterSetEdit::Id[] = "None";


NoByteArrayChecksumParameterSetEdit::NoByteArrayChecksumParameterSetEdit( QWidget* parent )
 : AbstractByteArrayChecksumParameterSetEdit( parent )
{}

void NoByteArrayChecksumParameterSetEdit::setParameterSet( const AbstractByteArrayChecksumParameterSet* parameterSet )
{
    Q_UNUSED( parameterSet );
}

void NoByteArrayChecksumParameterSetEdit::getParameterSet( AbstractByteArrayChecksumParameterSet* parameterSet ) const
{
    Q_UNUSED( parameterSet );
}

NoByteArrayChecksumParameterSetEdit::~NoByteArrayChecksumParameterSetEdit()
{}
